@@ -1,35 +1,31 @@
 
 /*
- *  agInit.c  $Id: agInit.c,v 4.9 2006/12/10 19:41:26 bkorb Exp $
+ *  agInit.c  $Id: agInit.c,v 4.12 2007/08/05 17:09:50 bkorb Exp $
  *
- *  Time-stamp:      "2006-12-10 11:02:12 bkorb"
+ *  Time-stamp:      "2007-07-04 11:14:11 bkorb"
  *
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by :mkfwd */
+/* static forward declarations maintained by mk-fwd */
 static void
 addSysEnv( char* pzEnvName );
 /* = = = END-STATIC-FORWARD = = = */
@@ -66,13 +62,16 @@ initialize( int arg_ct, char** arg_vec )
     pzLastScheme = NULL;
     procState = PROC_STATE_OPTIONS;
     /*
-     *  Set the last resort search directory first (lowest priority)
+     *  Set the last resort search directories first (lowest priority)
+     *  The lowest of the low is the config time install data dir.
+     *  Next is the *current* directory of this executable.
      */
+    SET_OPT_TEMPL_DIRS( "$@" );
     SET_OPT_TEMPL_DIRS( "$$/../share/autogen" );
 
     {
         char z[ 128 ] = "__autogen__";
-#if defined( HAVE_POSIX_SYSINFO )
+#if defined( HAVE_SOLARIS_SYSINFO )
         static const int nm[] = {
             SI_SYSNAME, SI_HOSTNAME, SI_ARCHITECTURE, SI_HW_PROVIDER,
 #ifdef      SI_PLATFORM
