@@ -1,32 +1,28 @@
 
 /*
  *  autogen.h
- *  $Id: autogen.h,v 4.27 2006/12/10 19:41:26 bkorb Exp $
+ *  $Id: autogen.h,v 4.31 2007/07/07 01:04:11 bkorb Exp $
  *
- *  Time-stamp:        "2006-12-10 11:11:17 bkorb"
- *  Last Committed:    $Date: 2006/12/10 19:41:26 $
+ *  Time-stamp:        "2007-07-06 11:23:43 bkorb"
+ *  Last Committed:    $Date: 2007/07/07 01:04:11 $
  *
  *  Global header file for AutoGen
- */
-
-/*
- *  AutoGen copyright 1992-2006 Bruce Korb
  *
- *  AutoGen is free software.
- *  You may redistribute it and/or modify it under the terms of the
- *  GNU General Public License, as published by the Free Software
- *  Foundation; either version 2, or (at your option) any later version.
+ *  This file is part of AutoGen.
+ *  AutoGen copyright (c) 1992-2007 by Bruce Korb - all rights reserved
  *
- *  AutoGen is distributed in the hope that it will be useful,
- *  but WITHOUT ANY WARRANTY; without even the implied warranty of
- *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU General Public License for more details.
+ * AutoGen is free software: you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License as published by the
+ * Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *  You should have received a copy of the GNU General Public License
- *  along with AutoGen.  See the file "COPYING".  If not,
- *  write to:  The Free Software Foundation, Inc.,
- *             51 Franklin Street, Fifth Floor,
- *             Boston, MA  02110-1301, USA.
+ * AutoGen is distributed in the hope that it will be useful, but
+ * WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License along
+ * with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 #ifndef AUTOGEN_BUILD
 #define AUTOGEN_BUILD 1
@@ -388,7 +384,6 @@ MODE int         guileFailure     VALUE( 0 );
  *  Definition Parsing Globals
  */
 MODE char*       pzDefineData     VALUE( NULL );
-MODE size_t      defineDataSize   VALUE( 0 );
 MODE char*       pz_token         VALUE( NULL );
 MODE te_dp_event lastToken        VALUE( DP_EV_INVALID );
 
@@ -415,6 +410,7 @@ MKSTRING( NotStr,     "ERROR: %s is not a string\n" );
 MKSTRING( DevNull,    "/dev/null" );
 MKSTRING( ShellEnv,   "SHELL" );
 MKSTRING( Format,     "format" );
+MKSTRING( FileFormat, "%s%s\0%s.%s" );
 MKSTRING( Nil,        "" );
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
